# Mkdocs Tech Docs Template

Build flexible technical documentation with a [GOV.UK style](https://design-system.service.gov.uk/) using [Material for MkDocs](https://squidfunk.github.io/mkdocs-material/).

Visit the [documentation website](https://ministryofjustice.github.io/mkdocs-tech-docs-template/) for more details.

 ⚠️ This template is under construction and should only be used for prototyping.